@@ -76,23 +76,16 @@ void SPIRVToLLVMDbgTran::addDbgInfoVersion() {
                    DEBUG_METADATA_VERSION);
 }
 
-DIFile *
-SPIRVToLLVMDbgTran::getDIFile(const std::string &FileName,
-                              Optional<DIFile::ChecksumInfo<StringRef>> CS,
-                              Optional<std::string> Source) {
+DIFile *SPIRVToLLVMDbgTran::getDIFile(
+    const std::string &FileName,
+    std::optional<DIFile::ChecksumInfo<StringRef>> CS) {
   return getOrInsert(FileMap, FileName, [=]() {
     SplitFileName Split(FileName);
     // Use the first builder from the map to crete DIFile since it's
     // relations with other debug metadata is not going through DICompileUnit
-    if (!Split.BaseName.empty()) {
-      if (Source.hasValue()) {
-        const StringRef SourceRef = StringRef(Source.getValue());
-        return BuilderMap.begin()->second->createFile(
-            Split.BaseName, Split.Path, CS, SourceRef);
-      }
+    if (!Split.BaseName.empty())
       return BuilderMap.begin()->second->createFile(Split.BaseName, Split.Path,
                                                     CS);
-    }
     return static_cast<DIFile *>(nullptr);
   });
 }
@@ -142,24 +135,11 @@ const std::string &SPIRVToLLVMDbgTran::getString(const SPIRVId Id) {
   return String->getStr();
 }
 
-Optional<std::string>
-SPIRVToLLVMDbgTran::getStringSourceContinued(const SPIRVId Id,
-                                             SPIRVExtInst *DebugInst) {
-  if (!isValidId(Id) || getDbgInst<SPIRVDebug::DebugInfoNone>(Id))
-    return {};
-  std::string Str = BM->get<SPIRVString>(Id)->getStr();
-  using namespace SPIRVDebug::Operand::SourceContinued;
-  for (auto *I : DebugInst->getContinuedInstructions()) {
-    const std::string TmpStr =
-        BM->get<SPIRVString>(I->getArguments()[TextIdx])->getStr();
-    Str.append(TmpStr);
-  }
-  return Str;
-}
-
 void SPIRVToLLVMDbgTran::transDbgInfo(const SPIRVValue *SV, Value *V) {
-  // A constant sampler does not have a corresponding SPIRVInstruction.
-  if (SV->getOpCode() == OpConstantSampler)
+  // Constant samplers and composites do not have a corresponding
+  // SPIRVInstruction, but they may be mapped to an LLVM Instruction.
+  if (SV->getOpCode() == OpConstantSampler ||
+      SV->getOpCode() == OpConstantComposite)
     return;
 
   if (Instruction *I = dyn_cast<Instruction>(V)) {
@@ -203,18 +183,11 @@ void SPIRVToLLVMDbgTran::appendToSourceLangLiteral(DICompileUnit *CompileUnit,
 }
 
 DICompileUnit *
-SPIRVToLLVMDbgTran::transCompilationUnit(const SPIRVExtInst *DebugInst,
-                                         const std::string CompilerVersion,
-                                         const std::string Flags) {
-  // Do nothing in case we have already translated the CU (e.g. during
-  // DebugEntryPoint translation)
-  if (BuilderMap[DebugInst->getId()])
-    return nullptr;
-
+SPIRVToLLVMDbgTran::transCompilationUnit(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
 
   using namespace SPIRVDebug::Operand::CompilationUnit;
-  assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
+  assert(Ops.size() == OperandCount && "Invalid number of operands");
   // We must preserve only one Dwarf version module level metadata
   // UpgradeDebugInfo from llvm/lib/IR/AutoUpgrade.cpp has already done all
   // work for us during linking stage leaving a single Dwarf version in the
@@ -240,39 +213,10 @@ SPIRVToLLVMDbgTran::transCompilationUnit(const SPIRVExtInst *DebugInst,
     InvalidSourceLang = true;
   }
 
-  BuilderMap[DebugInst->getId()] = std::make_unique<DIBuilder>(*M);
-
-  assert(BuilderMap.size() != 0 && "No debug compile units");
-  if (isNonSemanticDebugInfo(DebugInst->getExtSetKind())) {
-    // Only initialize once
-    if (BuilderMap.size() == 1)
-      setBuildIdentifierAndStoragePath();
-
-    // This assertion is a guard/reminder to update the Producer argument to
-    // createCompileUnit() if a new DebugInfo type is ever created
-    assert(DebugInst->getExtSetKind() ==
-               SPIRVEIS_NonSemantic_Shader_DebugInfo_100 ||
-           DebugInst->getExtSetKind() ==
-               SPIRVEIS_NonSemantic_Shader_DebugInfo_200);
-
-    auto *CompileUnit = BuilderMap[DebugInst->getId()]->createCompileUnit(
-        SourceLang, getFile(Ops[SourceIdx]),
-        DebugInst->getExtSetKind() == SPIRVEIS_NonSemantic_Shader_DebugInfo_100
-            ? CompilerVersion
-            : getString(Ops[ProducerIdx]),
-        false, Flags, 0, StoragePath,
-        DICompileUnit::DebugEmissionKind::FullDebug, BuildIdentifier);
-    if (InvalidSourceLang) {
-      appendToSourceLangLiteral(CompileUnit, OriginalSourceLang);
-    }
-    return CompileUnit;
-  }
-
-  // TODO: Remove this workaround once we switch to NonSemantic.Shader.* debug
-  // info by default
   auto Producer = findModuleProducer();
+  BuilderMap[DebugInst->getId()] = std::make_unique<DIBuilder>(*M);
   auto *CompileUnit = BuilderMap[DebugInst->getId()]->createCompileUnit(
-      SourceLang, getFile(Ops[SourceIdx]), Producer, false, Flags, 0);
+      SourceLang, getFile(Ops[SourceIdx]), Producer, false, "", 0);
   if (InvalidSourceLang) {
     appendToSourceLangLiteral(CompileUnit, OriginalSourceLang);
   }
@@ -282,9 +226,7 @@ SPIRVToLLVMDbgTran::transCompilationUnit(const SPIRVExtInst *DebugInst,
 DIBasicType *SPIRVToLLVMDbgTran::transTypeBasic(const SPIRVExtInst *DebugInst) {
   using namespace SPIRVDebug::Operand::TypeBasic;
   const SPIRVWordVec &Ops = DebugInst->getArguments();
-  assert((Ops.size() == OperandCountOCL ||
-          Ops.size() == OperandCountNonSemantic) &&
-         "Invalid number of operands");
+  assert(Ops.size() == OperandCount && "Invalid number of operands");
   StringRef Name = getString(Ops[NameIdx]);
   auto Tag = static_cast<SPIRVDebug::EncodingTag>(
       getConstantValueOrLiteral(Ops, EncodingIdx, DebugInst->getExtSetKind()));
@@ -315,7 +257,7 @@ DIType *SPIRVToLLVMDbgTran::transTypePointer(const SPIRVExtInst *DebugInst) {
   DIType *PointeeTy = nullptr;
   if (BM->getEntry(Ops[BaseTypeIdx])->getOpCode() != OpTypeVoid)
     PointeeTy = transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
-  llvm::Optional<unsigned> AS;
+  std::optional<unsigned> AS;
   SPIRVWord SC = getConstantValueOrLiteral(Ops, StorageClassIdx,
                                            DebugInst->getExtSetKind());
   if (SC != ~0U) // all ones denote no address space
@@ -359,7 +301,7 @@ SPIRVToLLVMDbgTran::transTypeArrayOpenCL(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   size_t TotalCount = 1;
   SmallVector<llvm::Metadata *, 8> Subscripts;
   // Ops looks like: { BaseType, count1|upperBound1, count2|upperBound2, ...,
@@ -375,11 +317,10 @@ SPIRVToLLVMDbgTran::transTypeArrayOpenCL(const SPIRVExtInst *DebugInst) {
           nullptr, LowerBound, UpperBound, nullptr));
       continue;
     }
-    const SPIRVExtInst *ExprUB, *ExprLB;
-    if ((ExprUB = getDbgInst<SPIRVDebug::Expression>(Ops[I])) &&
-        (ExprLB =
-             getDbgInst<SPIRVDebug::Expression>(Ops[Ops.size() / 2 + I]))) {
+    if (auto *ExprUB = getDbgInst<SPIRVDebug::Expression>(Ops[I])) {
       auto *UpperBound = transDebugInst<DIExpression>(ExprUB);
+      auto *ExprLB =
+          getDbgInst<SPIRVDebug::Expression>(Ops[Ops.size() / 2 + I]);
       auto *LowerBound = transDebugInst<DIExpression>(ExprLB);
       Subscripts.push_back(getDIBuilder(DebugInst).getOrCreateSubrange(
           nullptr, LowerBound, UpperBound, nullptr));
@@ -419,17 +360,14 @@ SPIRVToLLVMDbgTran::transTypeArrayNonSemantic(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   size_t TotalCount = 1;
   SmallVector<llvm::Metadata *, 8> Subscripts;
   if (DebugInst->getExtOp() == SPIRVDebug::TypeArray) {
     for (size_t I = SubrangesIdx; I < Ops.size(); ++I) {
       auto *SR = transDebugInst<DISubrange>(BM->get<SPIRVExtInst>(Ops[I]));
-      // LLVM 15 - exclusive workaround, get from a pointer union seem to be
-      // bugged
-      if (isa<ConstantInt *>(SR->getCount()))
-        if (auto *Count = SR->getCount().get<ConstantInt *>())
-          TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
+      if (auto *Count = SR->getCount().get<ConstantInt *>())
+        TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
       Subscripts.push_back(SR);
     }
   }
@@ -446,16 +384,13 @@ SPIRVToLLVMDbgTran::transTypeArrayDynamic(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   size_t TotalCount = 1;
   SmallVector<llvm::Metadata *, 8> Subscripts;
   for (size_t I = SubrangesIdx; I < Ops.size(); ++I) {
     auto *SR = transDebugInst<DISubrange>(BM->get<SPIRVExtInst>(Ops[I]));
-    // LLVM 15 - exclusive workaround, get from a pointer union seem to be
-    // bugged
-    if (isa<ConstantInt *>(SR->getCount()))
-      if (auto *Count = SR->getCount().get<ConstantInt *>())
-        TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
+    if (auto *Count = SR->getCount().get<ConstantInt *>())
+      TotalCount *= Count->getSExtValue() > 0 ? Count->getSExtValue() : 0;
     Subscripts.push_back(SR);
   }
   DINodeArray SubscriptArray =
@@ -492,7 +427,7 @@ SPIRVToLLVMDbgTran::transTypeVector(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   DIType *BaseTy =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[BaseTypeIdx]));
   SPIRVWord Count = getConstantValueOrLiteral(Ops, ComponentCountIdx,
                                               DebugInst->getExtSetKind());
   // Round up to a power of two.
@@ -501,7 +436,7 @@ SPIRVToLLVMDbgTran::transTypeVector(const SPIRVExtInst *DebugInst) {
   // Clang rounds up the memory size of vectors to a power of 2.
   // Vulkan allows vec3 to have a memory size of 12, but in RenderDoc memory
   // size is not derived from debug info.
-  const uint64_t Size = getDerivedSizeInBits(BaseTy) * bitCeil(Count);
+  uint64_t Size = getDerivedSizeInBits(BaseTy) * llvm::bit_ceil(Count);
 
   SmallVector<llvm::Metadata *, 8> Subscripts;
   Subscripts.push_back(getDIBuilder(DebugInst).getOrCreateSubrange(0, Count));
@@ -579,21 +514,7 @@ SPIRVToLLVMDbgTran::transTypeComposite(const SPIRVExtInst *DebugInst) {
   DebugInstCache[DebugInst] = CT;
   SmallVector<llvm::Metadata *, 8> EltTys;
   for (size_t I = FirstMemberIdx; I < Ops.size(); ++I) {
-    auto *MemberInst = BM->get<SPIRVExtInst>(Ops[I]);
-    if (MemberInst->getExtOp() == SPIRVDebug::TypeMember) {
-      auto *SPVMemberInst = BM->get<SPIRVExtInst>(Ops[I]);
-      DINode *MemberMD =
-          transTypeMember(SPVMemberInst, DebugInst, cast<DIScope>(CT));
-      EltTys.push_back(MemberMD);
-      DebugInstCache[SPVMemberInst] = MemberMD;
-    } else if (MemberInst->getExtOp() == SPIRVDebug::TypeInheritance) {
-      auto *SPVMemberInst = BM->get<SPIRVExtInst>(Ops[I]);
-      DINode *MemberMD = transTypeInheritance(SPVMemberInst, cast<DIType>(CT));
-      EltTys.push_back(MemberMD);
-      DebugInstCache[SPVMemberInst] = MemberMD;
-    } else {
-      EltTys.emplace_back(transDebugInst(BM->get<SPIRVExtInst>(Ops[I])));
-    }
+    EltTys.push_back(transDebugInst(BM->get<SPIRVExtInst>(Ops[I])));
   }
   DINodeArray Elements = getDIBuilder(DebugInst).getOrCreateArray(EltTys);
   getDIBuilder(DebugInst).replaceArrays(CT, Elements);
@@ -675,18 +596,8 @@ SPIRVToLLVMDbgTran::transTypeString(const SPIRVExtInst *DebugInst) {
                            0 /*AlignInBits*/, Encoding);
 }
 
-DINode *SPIRVToLLVMDbgTran::transTypeMember(const SPIRVExtInst *DebugInst,
-                                            const SPIRVExtInst *ParentInst,
-                                            DIScope *Scope) {
-  if (isNonSemanticDebugInfo(DebugInst->getExtSetKind()))
-    // In NonSemantic spec TypeMember doesn't have Scope parameter
-    return transTypeMemberNonSemantic(DebugInst, ParentInst, Scope);
-  return transTypeMemberOpenCL(DebugInst);
-}
-
-DINode *
-SPIRVToLLVMDbgTran::transTypeMemberOpenCL(const SPIRVExtInst *DebugInst) {
-  using namespace SPIRVDebug::Operand::TypeMember::OpenCL;
+DINode *SPIRVToLLVMDbgTran::transTypeMember(const SPIRVExtInst *DebugInst) {
+  using namespace SPIRVDebug::Operand::TypeMember;
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
 
@@ -695,7 +606,8 @@ SPIRVToLLVMDbgTran::transTypeMemberOpenCL(const SPIRVExtInst *DebugInst) {
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
   StringRef Name = getString(Ops[NameIdx]);
   DIScope *Scope = getScope(BM->getEntry(Ops[ParentIdx]));
-  DIType *BaseType = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  DIType *BaseType =
+      transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
   uint64_t OffsetInBits =
       BM->get<SPIRVConstant>(Ops[OffsetIdx])->getZExtIntValue();
   SPIRVWord SPIRVFlags =
@@ -710,6 +622,7 @@ SPIRVToLLVMDbgTran::transTypeMemberOpenCL(const SPIRVExtInst *DebugInst) {
   }
   if (SPIRVFlags & SPIRVDebug::FlagIsStaticMember)
     Flags |= DINode::FlagStaticMember;
+
   if (Flags & DINode::FlagStaticMember && Ops.size() > MinOperandCount) {
     SPIRVValue *ConstVal = BM->get<SPIRVValue>(Ops[ValueIdx]);
     assert(isConstantOpCode(ConstVal->getOpCode()) &&
@@ -726,56 +639,6 @@ SPIRVToLLVMDbgTran::transTypeMemberOpenCL(const SPIRVExtInst *DebugInst) {
                                                   Flags, BaseType);
 }
 
-DINode *
-SPIRVToLLVMDbgTran::transTypeMemberNonSemantic(const SPIRVExtInst *DebugInst,
-                                               const SPIRVExtInst *ParentInst,
-                                               DIScope *Scope) {
-  if (!Scope)
-    // Will be translated later when processing TypeMember's parent
-    return nullptr;
-  using namespace SPIRVDebug::Operand::TypeMember::NonSemantic;
-  const SPIRVWordVec &Ops = DebugInst->getArguments();
-  assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
-
-  DIFile *File = getFile(Ops[SourceIdx]);
-  const SPIRVWord LineNo =
-      getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
-  const StringRef Name = getString(Ops[NameIdx]);
-  DIType *BaseType =
-      transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
-  const uint64_t OffsetInBits =
-      BM->get<SPIRVConstant>(Ops[OffsetIdx])->getZExtIntValue();
-  const SPIRVWord SPIRVFlags =
-      getConstantValueOrLiteral(Ops, FlagsIdx, DebugInst->getExtSetKind());
-  DINode::DIFlags Flags = DINode::FlagZero;
-  if ((SPIRVDebug::FlagAccess & SPIRVFlags) == SPIRVDebug::FlagIsPublic) {
-    Flags |= DINode::FlagPublic;
-  } else if (SPIRVFlags & SPIRVDebug::FlagIsProtected) {
-    Flags |= DINode::FlagProtected;
-  } else if (SPIRVFlags & SPIRVDebug::FlagIsPrivate) {
-    Flags |= DINode::FlagPrivate;
-  }
-  if (SPIRVFlags & SPIRVDebug::FlagIsStaticMember)
-    Flags |= DINode::FlagStaticMember;
-  if (SPIRVFlags & SPIRVDebug::FlagBitField)
-    Flags |= DINode::FlagBitField;
-
-  if (Flags & DINode::FlagStaticMember && Ops.size() > MinOperandCount) {
-    SPIRVValue *ConstVal = BM->get<SPIRVValue>(Ops[ValueIdx]);
-    assert(isConstantOpCode(ConstVal->getOpCode()) &&
-           "Static member must be a constant");
-    llvm::Value *Val = SPIRVReader->transValue(ConstVal, nullptr, nullptr);
-    return getDIBuilder(DebugInst).createStaticMemberType(
-        Scope, Name, File, LineNo, BaseType, Flags, cast<llvm::Constant>(Val));
-  }
-  const uint64_t Size = BM->get<SPIRVConstant>(Ops[SizeIdx])->getZExtIntValue();
-  const uint64_t Alignment = 0;
-
-  return getDIBuilder(ParentInst)
-      .createMemberType(Scope, Name, File, LineNo, Size, Alignment,
-                        OffsetInBits, Flags, BaseType);
-}
-
 DINode *SPIRVToLLVMDbgTran::transTypeEnum(const SPIRVExtInst *DebugInst) {
   using namespace SPIRVDebug::Operand::TypeEnum;
   const SPIRVWordVec &Ops = DebugInst->getArguments();
@@ -808,7 +671,7 @@ DINode *SPIRVToLLVMDbgTran::transTypeEnum(const SPIRVExtInst *DebugInst) {
       UnderlyingType = transDebugInst<DIType>(static_cast<SPIRVExtInst *>(E));
     return getDIBuilder(DebugInst).createEnumerationType(
         Scope, Name, File, LineNo, SizeInBits, AlignInBits, Enumerators,
-        UnderlyingType, "", UnderlyingType);
+        UnderlyingType, "", Flags & SPIRVDebug::FlagIsEnumClass);
   }
 }
 
@@ -849,9 +712,9 @@ SPIRVToLLVMDbgTran::transTypePtrToMember(const SPIRVExtInst *DebugInst) {
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= OperandCount && "Invalid number of operands");
   SPIRVExtInst *Member = BM->get<SPIRVExtInst>(Ops[MemberTypeIdx]);
-  DIType *PointeeTy = transNonNullDebugType(Member);
+  DIType *PointeeTy = transDebugInst<DIType>(Member);
   SPIRVExtInst *ContainingTy = BM->get<SPIRVExtInst>(Ops[ParentIdx]);
-  DIType *BaseTy = transNonNullDebugType(ContainingTy);
+  DIType *BaseTy = transDebugInst<DIType>(ContainingTy);
   return getDIBuilder(DebugInst).createMemberPointerType(PointeeTy, BaseTy, 0);
 }
 
@@ -862,17 +725,10 @@ DINode *SPIRVToLLVMDbgTran::transLexicalBlock(const SPIRVExtInst *DebugInst) {
   DIFile *File = getFile(Ops[SourceIdx]);
   SPIRVWord LineNo =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
-  if (Ops.size() > MinOperandCount) {
+  if (Ops.size() > NameIdx) {
     StringRef Name = getString(Ops[NameIdx]);
-    bool InlinedNamespace = false;
-    if (DebugInst->getExtSetKind() ==
-        SPIRVEIS_NonSemantic_Shader_DebugInfo_200) {
-      SPIRVValue *V = BM->get<SPIRVValue>(Ops[InlineNamespaceIdx]);
-      Value *Var = SPIRVReader->transValue(V, nullptr, nullptr);
-      InlinedNamespace = cast<ConstantInt>(Var)->isOne();
-    }
     return getDIBuilder(DebugInst).createNameSpace(ParentScope, Name,
-                                                   InlinedNamespace);
+                                                   false /*inlined namespace*/);
   }
   unsigned Column = Ops[ColumnIdx];
   return getDIBuilder(DebugInst).createLexicalBlock(ParentScope, File, LineNo,
@@ -891,13 +747,10 @@ DINode *SPIRVToLLVMDbgTran::transLexicalBlockDiscriminator(
                                                         Disc);
 }
 
-DINode *SPIRVToLLVMDbgTran::transFunction(const SPIRVExtInst *DebugInst,
-                                          bool IsMainSubprogram) {
+DINode *SPIRVToLLVMDbgTran::transFunction(const SPIRVExtInst *DebugInst) {
   using namespace SPIRVDebug::Operand::Function;
   const SPIRVWordVec &Ops = DebugInst->getArguments();
-  assert(Ops.size() >= MinOperandCountNonSem && "Invalid number of operands");
-  if (!isNonSemanticDebugInfo(DebugInst->getExtSetKind()))
-    assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
+  assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
 
   StringRef Name = getString(Ops[NameIdx]);
   DISubroutineType *Ty =
@@ -931,25 +784,18 @@ DINode *SPIRVToLLVMDbgTran::transFunction(const SPIRVExtInst *DebugInst,
   bool IsDefinition = SPIRVDebugFlags & SPIRVDebug::FlagIsDefinition;
   bool IsOptimized = SPIRVDebugFlags & SPIRVDebug::FlagIsOptimized;
   bool IsLocal = SPIRVDebugFlags & SPIRVDebug::FlagIsLocal;
-  bool IsMainSubprogramFlag =
-      IsMainSubprogram ||
-      (!isNonSemanticDebugInfo(DebugInst->getExtSetKind()) &&
-       BM->isEntryPoint(spv::ExecutionModelKernel, Ops[FunctionIdIdx]));
-
-  DISubprogram::DISPFlags SPFlags = DISubprogram::toSPFlags(
-      IsLocal, IsDefinition, IsOptimized, DISubprogram::SPFlagNonvirtual,
-      IsMainSubprogramFlag);
+  bool IsMainSubprogram =
+      BM->isEntryPoint(spv::ExecutionModelKernel, Ops[FunctionIdIdx]);
+  DISubprogram::DISPFlags SPFlags =
+      DISubprogram::toSPFlags(IsLocal, IsDefinition, IsOptimized,
+                              DISubprogram::SPFlagNonvirtual, IsMainSubprogram);
 
   SPIRVWord ScopeLine =
       getConstantValueOrLiteral(Ops, ScopeLineIdx, DebugInst->getExtSetKind());
 
   // Function declaration descriptor
   DISubprogram *FD = nullptr;
-  if (isNonSemanticDebugInfo(DebugInst->getExtSetKind()) &&
-      Ops.size() > DeclarationNonSemIdx) {
-    FD = transDebugInst<DISubprogram>(
-        BM->get<SPIRVExtInst>(Ops[DeclarationNonSemIdx]));
-  } else if (Ops.size() > DeclarationIdx) {
+  if (Ops.size() > DeclarationIdx) {
     FD = transDebugInst<DISubprogram>(
         BM->get<SPIRVExtInst>(Ops[DeclarationIdx]));
   }
@@ -973,10 +819,8 @@ DINode *SPIRVToLLVMDbgTran::transFunction(const SPIRVExtInst *DebugInst,
   else {
     // Create targetFuncName mostly for Fortran trampoline function if it is
     // the case
-    StringRef TargetFunction = "";
-    if (DebugInst->getExtSetKind() ==
-            SPIRVEIS_NonSemantic_Shader_DebugInfo_200 &&
-        Ops.size() > TargetFunctionNameIdx) {
+    StringRef TargetFunction;
+    if (Ops.size() > TargetFunctionNameIdx) {
       TargetFunction = getString(Ops[TargetFunctionNameIdx]);
     }
     DIS = getDIBuilder(DebugInst).createFunction(
@@ -986,21 +830,11 @@ DINode *SPIRVToLLVMDbgTran::transFunction(const SPIRVExtInst *DebugInst,
         /*Annotations*/ nullptr, TargetFunction);
   }
   DebugInstCache[DebugInst] = DIS;
+  SPIRVId RealFuncId = Ops[FunctionIdIdx];
+  FuncMap[RealFuncId] = DIS;
 
-  // At this point, we don't have info about the function definition for
-  // NonSemantic.Shader debug info. If function definition is present, it'll be
-  // translated later within the function scope.
-  // For "default" debug info we do translate function body here.
-  if (!isNonSemanticDebugInfo(DebugInst->getExtSetKind()))
-    transFunctionBody(DIS, Ops[FunctionIdIdx]);
-
-  return DIS;
-}
-
-void SPIRVToLLVMDbgTran::transFunctionBody(DISubprogram *DIS, SPIRVId FuncId) {
-  FuncMap[FuncId] = DIS;
-
-  SPIRVEntry *E = BM->getEntry(FuncId);
+  // Function.
+  SPIRVEntry *E = BM->getEntry(Ops[FunctionIdIdx]);
   if (E->getOpCode() == OpFunction) {
     SPIRVFunction *BF = static_cast<SPIRVFunction *>(E);
     llvm::Function *F = SPIRVReader->transFunction(BF);
@@ -1008,18 +842,7 @@ void SPIRVToLLVMDbgTran::transFunctionBody(DISubprogram *DIS, SPIRVId FuncId) {
     if (!F->hasMetadata("dbg"))
       F->setMetadata("dbg", DIS);
   }
-}
-
-DINode *
-SPIRVToLLVMDbgTran::transFunctionDefinition(const SPIRVExtInst *DebugInst) {
-  using namespace SPIRVDebug::Operand::FunctionDefinition;
-  const SPIRVWordVec &Ops = DebugInst->getArguments();
-
-  SPIRVExtInst *Func = BM->get<SPIRVExtInst>(Ops[FunctionIdx]);
-  DISubprogram *LLVMFunc = cast<DISubprogram>(DebugInstCache[Func]);
-
-  transFunctionBody(LLVMFunc, Ops[DefinitionIdx]);
-  return nullptr;
+  return DIS;
 }
 
 DINode *SPIRVToLLVMDbgTran::transFunctionDecl(const SPIRVExtInst *DebugInst) {
@@ -1090,29 +913,13 @@ DINode *SPIRVToLLVMDbgTran::transFunctionDecl(const SPIRVExtInst *DebugInst) {
   return DIS;
 }
 
-MDNode *SPIRVToLLVMDbgTran::transEntryPoint(const SPIRVExtInst *DebugInst) {
-  using namespace SPIRVDebug::Operand::EntryPoint;
-  const SPIRVWordVec &Ops = DebugInst->getArguments();
-  assert(Ops.size() == OperandCount && "Invalid number of operands");
-
-  SPIRVExtInst *EP = BM->get<SPIRVExtInst>(Ops[EntryPointIdx]);
-  SPIRVExtInst *CU = BM->get<SPIRVExtInst>(Ops[CompilationUnitIdx]);
-  std::string Producer = getString(Ops[CompilerSignatureIdx]);
-  std::string CLArgs = getString(Ops[CommandLineArgsIdx]);
-
-  [[maybe_unused]] DICompileUnit *C =
-      transCompilationUnit(CU, Producer, CLArgs);
-
-  return transFunction(EP, true /*IsMainSubprogram*/);
-}
-
 MDNode *SPIRVToLLVMDbgTran::transGlobalVariable(const SPIRVExtInst *DebugInst) {
   using namespace SPIRVDebug::Operand::GlobalVariable;
   const SPIRVWordVec &Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
 
   StringRef Name = getString(Ops[NameIdx]);
-  DIType *Ty = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  DIType *Ty = transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
   DIFile *File = getFile(Ops[SourceIdx]);
   SPIRVWord LineNo =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
@@ -1178,7 +985,7 @@ DINode *SPIRVToLLVMDbgTran::transLocalVariable(const SPIRVExtInst *DebugInst) {
   DIFile *File = getFile(Ops[SourceIdx]);
   SPIRVWord LineNo =
       getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
-  DIType *Ty = transNonNullDebugType(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
+  DIType *Ty = transDebugInst<DIType>(BM->get<SPIRVExtInst>(Ops[TypeIdx]));
   DINode::DIFlags Flags = DINode::FlagZero;
   SPIRVWord SPIRVFlags =
       getConstantValueOrLiteral(Ops, FlagsIdx, DebugInst->getExtSetKind());
@@ -1338,20 +1145,12 @@ MDNode *SPIRVToLLVMDbgTran::transTypeTemplate(const SPIRVExtInst *DebugInst) {
 DINode *SPIRVToLLVMDbgTran::transImportedEntry(const SPIRVExtInst *DebugInst) {
   using namespace SPIRVDebug::Operand::ImportedEntity;
   const SPIRVWordVec &Ops = DebugInst->getArguments();
-  // FIXME: 'OpenCL/bugged' version is kept because it's hard to remove it
-  // It's W/A for missing 2nd index in OpenCL's implementation
-  const SPIRVWord OffsetIdx = isNonSemanticDebugInfo(DebugInst->getExtSetKind())
-                                  ? OperandCount - NonSemantic::OperandCount
-                                  : 0;
-
-  assert(Ops.size() == (OperandCount - OffsetIdx) &&
-         "Invalid number of operands");
-  DIScope *Scope = getScope(BM->getEntry(Ops[ParentIdx - OffsetIdx]));
-  SPIRVWord Line = getConstantValueOrLiteral(Ops, LineIdx - OffsetIdx,
-                                             DebugInst->getExtSetKind());
-  DIFile *File = getFile(Ops[SourceIdx - OffsetIdx]);
-  auto *Entity =
-      transDebugInst<DINode>(BM->get<SPIRVExtInst>(Ops[EntityIdx - OffsetIdx]));
+  assert(Ops.size() >= OperandCount && "Invalid number of operands");
+  DIScope *Scope = getScope(BM->getEntry(Ops[ParentIdx]));
+  SPIRVWord Line =
+      getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
+  DIFile *File = getFile(Ops[SourceIdx]);
+  auto *Entity = transDebugInst<DINode>(BM->get<SPIRVExtInst>(Ops[EntityIdx]));
   SPIRVWord Tag =
       getConstantValueOrLiteral(Ops, TagIdx, DebugInst->getExtSetKind());
   if (Tag == SPIRVDebug::ImportedModule) {
@@ -1377,7 +1176,11 @@ DINode *SPIRVToLLVMDbgTran::transImportedEntry(const SPIRVExtInst *DebugInst) {
     return getDIBuilder(DebugInst).createImportedDeclaration(Scope, Entity,
                                                              File, Line, Name);
   }
-  llvm_unreachable("Unexpected kind of imported entity!");
+  // FIXME: uncomment and fix following line, with existing bugs it's reachable.
+  // llvm_unreachable("Unexpected kind of imported entity!");
+  // Imported entity translation is broken. For example ImportedEntity is
+  // missing 2nd parameter.
+  return nullptr;
 }
 
 DINode *SPIRVToLLVMDbgTran::transModule(const SPIRVExtInst *DebugInst) {
@@ -1410,21 +1213,13 @@ MDNode *SPIRVToLLVMDbgTran::transExpression(const SPIRVExtInst *DebugInst) {
             Operands, OpCodeIdx, DebugInst->getExtSetKind()));
     Ops.push_back(SPIRV::DbgExpressionOpCodeMap::rmap(OpCode));
     for (unsigned I = 1, E = Operands.size(); I < E; ++I) {
-      Ops.push_back(
-          getConstantValueOrLiteral(Operands, I, DebugInst->getExtSetKind()));
+      Ops.push_back(Operands[I]);
     }
   }
   ArrayRef<uint64_t> Addr(Ops.data(), Ops.size());
   return getDIBuilder(DebugInst).createExpression(Addr);
 }
 
-DIType *
-SPIRVToLLVMDbgTran::transNonNullDebugType(const SPIRVExtInst *DebugInst) {
-  if (DebugInst->getExtOp() != SPIRVDebug::DebugInfoNone)
-    return transDebugInst<DIType>(DebugInst);
-  return getDIBuilder(DebugInst).createUnspecifiedType("SPIRV unknown type");
-}
-
 MDNode *SPIRVToLLVMDbgTran::transDebugInstImpl(const SPIRVExtInst *DebugInst) {
   switch (DebugInst->getExtOp()) {
   case SPIRVDebug::DebugInfoNone:
@@ -1481,12 +1276,6 @@ MDNode *SPIRVToLLVMDbgTran::transDebugInstImpl(const SPIRVExtInst *DebugInst) {
   case SPIRVDebug::FunctionDeclaration:
     return transFunctionDecl(DebugInst);
 
-  case SPIRVDebug::FunctionDefinition:
-    return transFunctionDefinition(DebugInst);
-
-  case SPIRVDebug::EntryPoint:
-    return transEntryPoint(DebugInst);
-
   case SPIRVDebug::GlobalVariable:
     return transGlobalVariable(DebugInst);
 
@@ -1500,7 +1289,7 @@ MDNode *SPIRVToLLVMDbgTran::transDebugInstImpl(const SPIRVExtInst *DebugInst) {
     return transDebugInlined(DebugInst);
 
   case SPIRVDebug::TypeInheritance:
-    return transTypeInheritance(DebugInst);
+    return transTypeInheritance(DebugInst, nullptr);
 
   case SPIRVDebug::TypeTemplateParameter:
     return transTypeTemplateParameter(DebugInst);
@@ -1523,9 +1312,6 @@ MDNode *SPIRVToLLVMDbgTran::transDebugInstImpl(const SPIRVExtInst *DebugInst) {
 
   case SPIRVDebug::Operation: // To be translated with transExpression
   case SPIRVDebug::Source:    // To be used by other instructions
-  case SPIRVDebug::SourceContinued:
-  case SPIRVDebug::BuildIdentifier: // To be used by transCompilationUnit
-  case SPIRVDebug::StoragePath:     // To be used by transCompilationUnit
     return nullptr;
 
   case SPIRVDebug::Expression:
@@ -1559,7 +1345,6 @@ SPIRVToLLVMDbgTran::transDebugIntrinsic(const SPIRVExtInst *DebugInst,
   switch (DebugInst->getExtOp()) {
   case SPIRVDebug::Scope:
   case SPIRVDebug::NoScope:
-  case SPIRVDebug::FunctionDefinition:
     return nullptr;
   case SPIRVDebug::Declare: {
     using namespace SPIRVDebug::Operand::DebugDeclare;
@@ -1607,16 +1392,7 @@ DebugLoc SPIRVToLLVMDbgTran::transDebugScope(const SPIRVInstruction *Inst) {
   unsigned Col = 0;
   MDNode *Scope = nullptr;
   MDNode *InlinedAt = nullptr;
-
-  // If DebugLine and OpLine are both active give DebugLine priority
-  if (auto DL = Inst->getDebugLine()) {
-    using namespace SPIRVDebug::Operand::DebugLine;
-    const SPIRVWordVec DebugLineArgs = DL->getArguments();
-    Line =
-        getConstantValueOrLiteral(DebugLineArgs, StartIdx, DL->getExtSetKind());
-    Col = getConstantValueOrLiteral(DebugLineArgs, ColumnStartIdx,
-                                    DL->getExtSetKind());
-  } else if (auto L = Inst->getLine()) {
+  if (auto L = Inst->getLine()) {
     Line = L->getLine();
     Col = L->getColumn();
   }
@@ -1633,12 +1409,7 @@ DebugLoc SPIRVToLLVMDbgTran::transDebugScope(const SPIRVInstruction *Inst) {
 }
 
 MDNode *SPIRVToLLVMDbgTran::transDebugInlined(const SPIRVExtInst *DebugInst) {
-  // There is a Column operand in NonSemantic.Shader.200 spec
-  if (DebugInst->getExtSetKind() ==
-      SPIRV::SPIRVEIS_NonSemantic_Shader_DebugInfo_200)
-    return transDebugInlinedNonSemanticShader200(DebugInst);
-
-  using namespace SPIRVDebug::Operand::InlinedAt::OpenCL;
+  using namespace SPIRVDebug::Operand::InlinedAt;
   SPIRVWordVec Ops = DebugInst->getArguments();
   assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
   SPIRVWord Line =
@@ -1654,25 +1425,6 @@ MDNode *SPIRVToLLVMDbgTran::transDebugInlined(const SPIRVExtInst *DebugInst) {
   return DILocation::getDistinct(M->getContext(), Line, Col, Scope, InlinedAt);
 }
 
-MDNode *SPIRVToLLVMDbgTran::transDebugInlinedNonSemanticShader200(
-    const SPIRVExtInst *DebugInst) {
-  using namespace SPIRVDebug::Operand::InlinedAt::NonSemantic;
-  SPIRVWordVec Ops = DebugInst->getArguments();
-  assert(Ops.size() >= MinOperandCount && "Invalid number of operands");
-  const SPIRVWord Line =
-      getConstantValueOrLiteral(Ops, LineIdx, DebugInst->getExtSetKind());
-  const unsigned Col =
-      getConstantValueOrLiteral(Ops, ColumnIdx, DebugInst->getExtSetKind());
-  DILocalScope *Scope =
-      cast<DILocalScope>(getScope(BM->getEntry(Ops[ScopeIdx])));
-  DILocation *InlinedAt = nullptr;
-  if (Ops.size() > InlinedIdx) {
-    InlinedAt =
-        transDebugInst<DILocation>(BM->get<SPIRVExtInst>(Ops[InlinedIdx]));
-  }
-  return DILocation::getDistinct(M->getContext(), Line, Col, Scope, InlinedAt);
-}
-
 void SPIRVToLLVMDbgTran::finalize() {
   if (!Enable)
     return;
@@ -1686,85 +1438,12 @@ DIFile *SPIRVToLLVMDbgTran::getFile(const SPIRVId SourceId) {
   assert(Source->getExtOp() == SPIRVDebug::Source &&
          "DebugSource instruction is expected");
   SPIRVWordVec SourceArgs = Source->getArguments();
-  assert(SourceArgs.size() >= MinOperandCount && "Invalid number of operands");
-  if (SourceArgs.size() == MinOperandCount)
-    return getDIFile(getString(SourceArgs[FileIdx]));
-
-  if (!isNonSemanticDebugInfo(Source->getExtSetKind())) {
-    const std::string ChecksumStr =
-        getDbgInst<SPIRVDebug::DebugInfoNone>(SourceArgs[TextIdx])
-            ? ""
-            : getString(SourceArgs[TextIdx]);
-    return getDIFile(getString(SourceArgs[FileIdx]),
-                     ParseChecksum(ChecksumStr));
-  }
-
-  Optional<DIFile::ChecksumInfo<StringRef>> CS;
-  SPIRVWord StrIdx = SourceArgs[TextIdx];
-  if (Source->getExtSetKind() == SPIRVEIS_NonSemantic_Shader_DebugInfo_200) {
-    if (SourceArgs.size() >= MaxOperandCount - 1) {
-      // 2 optional parameters are ChecksumKind and ChecksumValue - they should
-      // go together
-      if (!getDbgInst<SPIRVDebug::DebugInfoNone>(SourceArgs[ChecksumKind]) &&
-          !getDbgInst<SPIRVDebug::DebugInfoNone>(SourceArgs[ChecksumValue])) {
-        const llvm::DIFile::ChecksumKind Kind = SPIRV::DbgChecksumKindMap::rmap(
-            static_cast<SPIRVDebug::FileChecksumKind>(
-                BM->get<SPIRVConstant>(SourceArgs[ChecksumKind])
-                    ->getZExtIntValue()));
-        const StringRef Checksum = getString(SourceArgs[ChecksumValue]);
-        const size_t ChecksumEndPos = Checksum.find_if_not(llvm::isHexDigit);
-        CS.emplace(Kind, Checksum.substr(0, ChecksumEndPos));
-      }
-    }
-
-    // Among optional parameters - text is always the last one (either 1st or
-    // 3rd)
-    if (SourceArgs.size() == MaxOperandCount ||
-        SourceArgs.size() == MaxOperandCount - 2)
-      StrIdx = SourceArgs[TextNonSemIdx];
-    else
-      StrIdx = SPIRVID_INVALID;
-  }
-
-  return getDIFile(getString(SourceArgs[FileIdx]), CS,
-                   getStringSourceContinued(StrIdx, Source));
-}
-
-void SPIRVToLLVMDbgTran::setBuildIdentifierAndStoragePath() {
-#ifndef NDEBUG
-  bool FoundBuildIdentifier{false};
-  bool FoundStoragePath{false};
-#endif
-
-  for (SPIRVExtInst *EI : BM->getDebugInstVec()) {
-    if (EI->getExtOp() == SPIRVDebug::BuildIdentifier) {
-      using namespace SPIRVDebug::Operand::BuildIdentifier;
-      SPIRVWordVec BuildIdentifierArgs = EI->getArguments();
-      assert(BuildIdentifierArgs.size() == OperandCount &&
-             "Invalid number of operands");
-      assert(!FoundBuildIdentifier &&
-             "More than one BuildIdentifier instruction not allowed");
-      BuildIdentifier = strtoull(
-          getString(BuildIdentifierArgs[IdentifierIdx]).c_str(), NULL, 10);
-#ifndef NDEBUG
-      FoundBuildIdentifier = true;
-#endif
-    } else if (EI->getExtOp() == SPIRVDebug::StoragePath) {
-      using namespace SPIRVDebug::Operand::StoragePath;
-      SPIRVWordVec StoragePathArgs = EI->getArguments();
-      assert(StoragePathArgs.size() == OperandCount &&
-             "Invalid number of operands");
-      assert(!FoundStoragePath &&
-             "More than one StoragePath instruction not allowed");
-      StoragePath = getString(StoragePathArgs[PathIdx]);
-#ifndef NDEBUG
-      FoundStoragePath = true;
-#endif
-    }
-  }
-  assert(((FoundBuildIdentifier && FoundStoragePath) ||
-          (!FoundBuildIdentifier && !FoundStoragePath)) &&
-         "BuildIdentifier and StoragePath must both be set or both unset");
+  assert(SourceArgs.size() == OperandCount && "Invalid number of operands");
+  std::string ChecksumStr =
+      getDbgInst<SPIRVDebug::DebugInfoNone>(SourceArgs[TextIdx])
+          ? ""
+          : getString(SourceArgs[TextIdx]);
+  return getDIFile(getString(SourceArgs[FileIdx]), ParseChecksum(ChecksumStr));
 }
 
 DIBuilder &SPIRVToLLVMDbgTran::getDIBuilder(const SPIRVExtInst *DebugInst) {
@@ -1776,8 +1455,7 @@ DIBuilder &SPIRVToLLVMDbgTran::getDIBuilder(const SPIRVExtInst *DebugInst) {
       return *BuilderMap.begin()->second;
     const SPIRVWordVec &Ops = DebugInst->getArguments();
     SPIRVWord ParentScopeIdx = 0;
-    if (!hasDbgInstParentScopeIdx(DebugInst->getExtOp(), ParentScopeIdx,
-                                  DebugInst->getExtSetKind()))
+    if (!hasDbgInstParentScopeIdx(DebugInst->getExtOp(), ParentScopeIdx))
       return *BuilderMap.begin()->second;
     if (SPIRVEntry *Scope = BM->getEntry(Ops[ParentScopeIdx])) {
       DebugInst = static_cast<SPIRVExtInst *>(Scope);
@@ -1809,11 +1487,11 @@ std::string SPIRVToLLVMDbgTran::findModuleProducer() {
   return "spirv";
 }
 
-Optional<DIFile::ChecksumInfo<StringRef>>
+std::optional<DIFile::ChecksumInfo<StringRef>>
 SPIRVToLLVMDbgTran::ParseChecksum(StringRef Text) {
   // Example of "Text" variable:
   // "SomeInfo//__CSK_MD5:7bb56387968a9caa6e9e35fff94eaf7b:OtherInfo"
-  Optional<DIFile::ChecksumInfo<StringRef>> CS;
+  std::optional<DIFile::ChecksumInfo<StringRef>> CS;
   auto KindPos = Text.find(SPIRVDebug::ChecksumKindPrefx);
   if (KindPos != StringRef::npos) {
     auto ColonPos = Text.find(":", KindPos);
@@ -1822,7 +1500,7 @@ SPIRVToLLVMDbgTran::ParseChecksum(StringRef Text) {
     auto Checksum = Text.substr(ColonPos).ltrim(':');
     if (auto Kind = DIFile::getChecksumKind(KindStr)) {
       size_t ChecksumEndPos = Checksum.find_if_not(llvm::isHexDigit);
-      CS.emplace(Kind.getValue(), Checksum.substr(0, ChecksumEndPos));
+      CS.emplace(Kind.value(), Checksum.substr(0, ChecksumEndPos));
     }
   }
   return CS;
