@@ -46,6 +46,7 @@
 #include "OCLTypeToSPIRV.h"
 #include "OCLUtil.h"
 #include "SPIRVBasicBlock.h"
+#include "SPIRVBuiltinHelper.h"
 #include "SPIRVEntry.h"
 #include "SPIRVEnum.h"
 #include "SPIRVFunction.h"
@@ -68,7 +69,7 @@ using namespace OCLUtil;
 
 namespace SPIRV {
 
-class LLVMToSPIRVBase {
+class LLVMToSPIRVBase : protected BuiltinCallHelper {
 public:
   LLVMToSPIRVBase(SPIRVModule *SMod);
   bool runLLVMToSPIRV(Module &Mod);
@@ -86,9 +87,7 @@ public:
   SPIRVType *transPointerType(SPIRVType *PointeeTy, unsigned AddrSpace);
   SPIRVType *transSPIRVOpaqueType(StringRef STName, unsigned AddrSpace);
   SPIRVType *
-  transSPIRVJointOrCooperativeMatrixType(SmallVector<std::string, 8> Postfixes,
-                                         bool IsCooperative = false);
-  // SPIRVType* transSPIRVCooperativeMatrixKHRType();
+  transSPIRVJointMatrixINTELType(SmallVector<std::string, 8> Postfixes);
   /// Use the type scavenger to get the correct type for V. This is equivalent
   /// to transType(V->getType()) if V is not a pointer type; otherwise, it tries
   /// to pick an appropriate pointee type for V.
@@ -107,7 +106,6 @@ public:
   bool transSourceLanguage();
   bool transExtension();
   bool transBuiltinSet();
-  bool transWorkItemBuiltinCallsToVariables();
   bool isKnownIntrinsic(Intrinsic::ID Id);
   SPIRVValue *transIntrinsicInst(IntrinsicInst *Intrinsic, SPIRVBasicBlock *BB);
   enum class FPBuiltinType {
@@ -135,6 +133,8 @@ public:
   void transFPGAFunctionMetadata(SPIRVFunction *BF, Function *F);
   void transAuxDataInst(SPIRVFunction *BF, Function *F);
   void transFunctionMetadataAsExecutionMode(SPIRVFunction *BF, Function *F);
+  void transFunctionMetadataAsUserSemanticDecoration(SPIRVFunction *BF,
+                                                     Function *F);
   bool transGlobalVariables();
 
   Op transBoolOpCode(SPIRVValue *Opn, Op OC);
@@ -144,6 +144,9 @@ public:
   bool transExecutionMode();
   void transFPContract();
   SPIRVValue *transConstant(Value *V);
+  /// Translate a reference to a constant in a constant expression. This may
+  /// involve inserting extra bitcasts to correct type issues.
+  SPIRVValue *transConstantUse(Constant *V);
   SPIRVValue *transValue(Value *V, SPIRVBasicBlock *BB,
                          bool CreateForward = true,
                          FuncTransMode FuncTrans = FuncTransMode::Decl);
@@ -192,7 +195,7 @@ private:
   SPIRVWord SrcLangVer;
   std::unique_ptr<LLVMToSPIRVDbgTran> DbgTran;
   std::unique_ptr<CallGraph> CG;
-  OCLTypeToSPIRVBase *OCLTypeToSPIRVPtr;
+  OCLTypeToSPIRVBase *OCLTypeToSPIRVPtr = nullptr;
   std::vector<llvm::Instruction *> UnboundInst;
   std::unique_ptr<SPIRVTypeScavenger> Scavenger;
 
