@@ -149,7 +149,7 @@ template <typename K> SPIRVCapVec getCapability(K Key) {
 #define ADD_VEC_INIT(Cap, ...)                                                 \
   {                                                                            \
     SPIRVCapabilityKind C[] = __VA_ARGS__;                                     \
-    const SPIRVCapVec V(C, C + sizeof(C) / sizeof(C[0]));                      \
+    SPIRVCapVec V(C, C + sizeof(C) / sizeof(C[0]));                            \
     add(Cap, V);                                                               \
   }
 
@@ -205,10 +205,6 @@ template <> inline void SPIRVMap<SPIRVCapabilityKind, SPIRVCapVec>::init() {
                {CapabilitySubgroupAvcMotionEstimationINTEL});
   ADD_VEC_INIT(CapabilitySubgroupAvcMotionEstimationChromaINTEL,
                {CapabilitySubgroupAvcMotionEstimationIntraINTEL});
-  ADD_VEC_INIT(internal::CapabilityJointMatrixWIInstructionsINTEL,
-               {internal::CapabilityJointMatrixINTEL});
-  ADD_VEC_INIT(internal::CapabilityCooperativeMatrixPrefetchINTEL,
-               {CapabilityCooperativeMatrixKHR});
   ADD_VEC_INIT(internal::CapabilityCooperativeMatrixCheckedInstructionsINTEL,
                {CapabilityCooperativeMatrixKHR});
 }
@@ -275,7 +271,7 @@ template <> inline void SPIRVMap<SPIRVExecutionModeKind, SPIRVCapVec>::init() {
                {CapabilityVectorComputeINTEL});
   ADD_VEC_INIT(internal::ExecutionModeFastCompositeKernelINTEL,
                {internal::CapabilityFastCompositeINTEL});
-  ADD_VEC_INIT(internal::ExecutionModeStreamingInterfaceINTEL,
+  ADD_VEC_INIT(ExecutionModeStreamingInterfaceINTEL,
                {CapabilityFPGAKernelAttributesINTEL});
   ADD_VEC_INIT(ExecutionModeNamedBarrierCountINTEL,
                {CapabilityVectorComputeINTEL});
@@ -380,7 +376,6 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
   ADD_VEC_INIT(DecorationSample, {CapabilitySampleRateShading});
   ADD_VEC_INIT(DecorationInvariant, {CapabilityShader});
   ADD_VEC_INIT(DecorationConstant, {CapabilityKernel});
-  ADD_VEC_INIT(DecorationUniform, {CapabilityShader});
   ADD_VEC_INIT(DecorationSaturatedConversion, {CapabilityKernel});
   ADD_VEC_INIT(DecorationStream, {CapabilityGeometryStreams});
   ADD_VEC_INIT(DecorationLocation, {CapabilityShader});
@@ -454,16 +449,15 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
   ADD_VEC_INIT(DecorationStallEnableINTEL,
                {CapabilityFPGAClusterAttributesINTEL});
   ADD_VEC_INIT(DecorationFuseLoopsInFunctionINTEL, {CapabilityLoopFuseINTEL});
-  ADD_VEC_INIT(internal::DecorationMathOpDSPModeINTEL,
-               {internal::CapabilityFPGADSPControlINTEL});
-  ADD_VEC_INIT(internal::DecorationInitiationIntervalINTEL,
-               {internal::CapabilityFPGAInvocationPipeliningAttributesINTEL});
-  ADD_VEC_INIT(internal::DecorationMaxConcurrencyINTEL,
-               {internal::CapabilityFPGAInvocationPipeliningAttributesINTEL});
-  ADD_VEC_INIT(internal::DecorationPipelineEnableINTEL,
-               {internal::CapabilityFPGAInvocationPipeliningAttributesINTEL});
+  ADD_VEC_INIT(DecorationMathOpDSPModeINTEL, {CapabilityFPGADSPControlINTEL});
+  ADD_VEC_INIT(DecorationInitiationIntervalINTEL,
+               {CapabilityFPGAInvocationPipeliningAttributesINTEL});
+  ADD_VEC_INIT(DecorationMaxConcurrencyINTEL,
+               {CapabilityFPGAInvocationPipeliningAttributesINTEL});
+  ADD_VEC_INIT(DecorationPipelineEnableINTEL,
+               {CapabilityFPGAInvocationPipeliningAttributesINTEL});
   ADD_VEC_INIT(internal::DecorationRuntimeAlignedINTEL,
-               {internal::CapabilityRuntimeAlignedAttributeINTEL});
+               {CapabilityRuntimeAlignedAttributeINTEL});
   ADD_VEC_INIT(internal::DecorationHostAccessINTEL,
                {internal::CapabilityGlobalVariableDecorationsINTEL});
   ADD_VEC_INIT(internal::DecorationInitModeINTEL,
@@ -482,6 +476,24 @@ template <> inline void SPIRVMap<Decoration, SPIRVCapVec>::init() {
                {internal::CapabilityCacheControlsINTEL});
   ADD_VEC_INIT(internal::DecorationCacheControlStoreINTEL,
                {internal::CapabilityCacheControlsINTEL});
+  ADD_VEC_INIT(DecorationConduitKernelArgumentINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationRegisterMapKernelArgumentINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationMMHostInterfaceAddressWidthINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationMMHostInterfaceDataWidthINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationMMHostInterfaceLatencyINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationMMHostInterfaceReadWriteModeINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationMMHostInterfaceMaxBurstINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationMMHostInterfaceWaitRequestINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
+  ADD_VEC_INIT(DecorationStableKernelArgumentINTEL,
+               {CapabilityFPGAArgumentInterfacesINTEL});
   ADD_VEC_INIT(DecorationFPMaxErrorDecorationINTEL,
                {CapabilityFPMaxErrorINTEL});
 }
