@@ -14,8 +14,6 @@ _SPIRV_OP_INTERNAL(JointMatrixUSMadINTEL, internal::OpJointMatrixUSMadINTEL)
 _SPIRV_OP_INTERNAL(JointMatrixUUMadINTEL, internal::OpJointMatrixUUMadINTEL)
 _SPIRV_OP_INTERNAL(JointMatrixWorkItemLengthINTEL,
                    internal::OpJointMatrixWorkItemLengthINTEL)
-_SPIRV_OP_INTERNAL(JointMatrixGetElementCoordINTEL,
-                   internal::OpJointMatrixGetElementCoordINTEL)
 _SPIRV_OP_INTERNAL(CooperativeMatrixLoadCheckedINTEL,
                    internal::OpCooperativeMatrixLoadCheckedINTEL)
 _SPIRV_OP_INTERNAL(CooperativeMatrixStoreCheckedINTEL,
@@ -27,3 +25,9 @@ _SPIRV_OP_INTERNAL(ComplexFDivINTEL, internal::ComplexFDivINTEL)
 _SPIRV_OP_INTERNAL(MaskedGatherINTEL, internal::OpMaskedGatherINTEL)
 _SPIRV_OP_INTERNAL(MaskedScatterINTEL, internal::OpMaskedScatterINTEL)
 _SPIRV_OP_INTERNAL(RoundFToTF32INTEL, internal::RoundFToTF32INTEL)
+_SPIRV_OP_INTERNAL(ConvertHandleToImageINTEL,
+                   internal::ConvertHandleToImageINTEL)
+_SPIRV_OP_INTERNAL(ConvertHandleToSamplerINTEL,
+                   internal::ConvertHandleToSamplerINTEL)
+_SPIRV_OP_INTERNAL(ConvertHandleToSampledImageINTEL,
+                   internal::ConvertHandleToSampledImageINTEL)
