@@ -93,6 +93,7 @@ public:
   bool isTypeOpaque() const;
   bool isTypePointer() const;
   bool isTypeSampler() const;
+  bool isTypeSampledImage() const;
   bool isTypeStruct() const;
   bool isTypeVector() const;
   bool isTypeJointMatrixINTEL() const;
@@ -168,7 +169,7 @@ public:
     }
     return CV;
   }
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+  std::optional<ExtensionID> getRequiredExtension() const override {
     switch (BitWidth) {
     case 8:
     case 16:
@@ -778,7 +779,7 @@ public:
 protected:
   _SPIRV_DEF_ENCDEC1(Id)
   void validate() const override { SPIRVEntry::validate(); }
-  SPIRVId Opn;
+  SPIRVId Opn = SPIRVID_INVALID;
 };
 
 template <Op TheOpCode>
@@ -896,14 +897,14 @@ public:
     return getVec(CapabilityVectorComputeINTEL);
   }
 
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+  std::optional<ExtensionID> getRequiredExtension() const override {
     return {ExtensionID::SPV_INTEL_vector_compute};
   }
 
-  bool hasAccessQualifier() const { return AccessKind.hasValue(); }
+  bool hasAccessQualifier() const { return AccessKind.has_value(); }
   SPIRVAccessQualifierKind getAccessQualifier() const {
     assert(hasAccessQualifier());
-    return AccessKind.getValue();
+    return AccessKind.value();
   }
 
 protected:
@@ -919,7 +920,7 @@ protected:
   }
 
 private:
-  llvm::Optional<SPIRVAccessQualifierKind> AccessKind;
+  std::optional<SPIRVAccessQualifierKind> AccessKind;
 };
 
 // SPV_INTEL_device_side_avc_motion_estimation extension types
@@ -946,7 +947,7 @@ public:
     return getVec(CapabilitySubgroupAvcMotionEstimationINTEL);
   }
 
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+  std::optional<ExtensionID> getRequiredExtension() const override {
     return ExtensionID::SPV_INTEL_device_side_avc_motion_estimation;
   }
 
@@ -1001,7 +1002,7 @@ public:
     return getVec(CapabilitySubgroupAvcMotionEstimationINTEL);
   }
 
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+  std::optional<ExtensionID> getRequiredExtension() const override {
     return ExtensionID::SPV_INTEL_device_side_avc_motion_estimation;
   }
 
@@ -1010,7 +1011,7 @@ public:
 protected:
   _SPIRV_DEF_ENCDEC1(Id)
   void validate() const override { SPIRVEntry::validate(); }
-  SPIRVId Opn;
+  SPIRVId Opn = SPIRVID_INVALID;
 };
 
 template <Op TheOpCode>
@@ -1052,7 +1053,7 @@ public:
     return getVec(internal::CapabilityTokenTypeINTEL);
   }
 
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+  std::optional<ExtensionID> getRequiredExtension() const override {
     return ExtensionID::SPV_INTEL_token_type;
   }
 
@@ -1073,7 +1074,7 @@ public:
   // Incomplete constructor
   SPIRVTypeJointMatrixINTEL();
   _SPIRV_DCL_ENCDEC
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+  std::optional<ExtensionID> getRequiredExtension() const override {
     return ExtensionID::SPV_INTEL_joint_matrix;
   }
   SPIRVCapVec getRequiredCapability() const override {
@@ -1105,7 +1106,7 @@ public:
   // Incomplete constructor
   SPIRVTypeCooperativeMatrixKHR();
   _SPIRV_DCL_ENCDEC
-  llvm::Optional<ExtensionID> getRequiredExtension() const override {
+  std::optional<ExtensionID> getRequiredExtension() const override {
     return ExtensionID::SPV_KHR_cooperative_matrix;
   }
   SPIRVCapVec getRequiredCapability() const override {
